# eric7.WebBrowser.Bookmarks.BookmarksImporters.XbelImporter

Module implementing an importer for XBEL files.

### Global Attributes

None

### Classes

XbelImporter | Class implementing the XBEL bookmarks importer.

### Functions

createImporter | Constructor
getImporterInfo | Module function to get information for the given XBEL source id.

## XbelImporter

Class implementing the XBEL bookmarks importer.

### Derived from

BookmarksImporter

### Class Attributes

None

### Class Methods

None

### Methods

XbelImporter | Constructor
importedBookmarks | Public method to get the imported bookmarks.
open | Public method to open the bookmarks file.
setPath | Public method to set the path of the bookmarks file or directory.

### Static Methods

None

#### XbelImporter (Constructor)

XbelImporter(sourceId="", parent=None)

Constructor

sourceId (str (optional))
  source ID (defaults to "")
parent (QObject (optional))
  reference to the parent object (defaults to None)

#### XbelImporter.importedBookmarks

importedBookmarks()

Public method to get the imported bookmarks.

Return:
  imported bookmarks (BookmarkNode)

#### XbelImporter.open

open()

Public method to open the bookmarks file.

Return:
  flag indicating success (boolean)

#### XbelImporter.setPath

setPath(path)

Public method to set the path of the bookmarks file or directory.

path
  bookmarks file or directory (string)

Up

## createImporter

createImporter(sourceId="", parent=None)

Constructor

sourceId (str (optional))
  source ID (defaults to "")
parent (QObject (optional))
  reference to the parent object (defaults to None)

Return:
  reference to the instantiated importer object

Return Type:
  XbelImporter

Up

## getImporterInfo

getImporterInfo(sourceId)

Module function to get information for the given XBEL source id.

sourceId
  id of the browser ("chrome" or "chromium")

Return:
  tuple with an icon (QPixmap), readable name (string), name of the default bookmarks file (string), an info text (string), a prompt (string) and the default directory of the bookmarks file (string)

Raises ValueError:
  raised to indicate an invalid browser ID

Up